@@ -5,7 +5,7 @@ from time_series_dataset_generator import make_time_series_dataset
 
 
 class FlightSeriesDataset(TimeSeriesDataset):
-    def __init__(self, pattern_length, n_to_predict, except_last_n, augmentation=0, stride='auto'):
+    def __init__(self, pattern_length, n_to_predict, except_last_n, augmentation=0, stride='auto', generate_test_dataset = False):
         flights = sns.load_dataset("flights")
         input_features_labels = ['month', 'year']
         output_features_labels = ['passengers']
@@ -25,7 +25,8 @@ class FlightSeriesDataset(TimeSeriesDataset):
             except_last_n,
             augmentation = augmentation,
             stride = stride,
-            overlap = past_pattern_length - n_to_predict
+            overlap = past_pattern_length - n_to_predict,
+            generate_test_dataset = generate_test_dataset
         )
         self.wrap(tsd)
 
