@@ -1,7 +1,6 @@
 import numpy as np
 from time_series_generator import TimeseriesGenerator
 import pandas as pd
-from sklearn.model_selection import train_test_split
 from time_series_dataset import TimeSeriesDataset
 import sys
 
@@ -14,12 +13,12 @@ def make_predictor(values, features_labels):
     features = _make_features(values, features_labels)
     return _raw_make_predictor(features), [feature.Name for feature in features]
 
-def make_time_series_dataset(input_df, pattern_length, n_to_predict, input_features_labels, output_features_labels, except_last_n, augmentation=0, stride='auto', shuffle=False, overlap = 0):
+def make_time_series_dataset(input_df, pattern_length, n_to_predict, input_features_labels, output_features_labels, except_last_n, augmentation=0, stride='auto', shuffle=False, overlap = 0, generate_test_dataset = False):
     def _make_regression(cd, pattern_length, input_features_labels, output_features_labels, n_to_predict, augmentation, stride, shuffle):
         def generate_timeseries(cd, pattern_length, n_to_predict, augmentation, stride, shuffle):
             tg = TimeseriesGenerator(
-                input_df,
-                input_df,
+                cd,
+                cd,
                 pattern_length - n_to_predict, # past_pattern_length
                 length_output = n_to_predict,
                 augmentation=augmentation,
@@ -46,8 +45,8 @@ def make_time_series_dataset(input_df, pattern_length, n_to_predict, input_featu
         _y, labels_y = make_predictor(output_values, output_features_labels)
 
         return _x, _y, {'x': labels_x, 'y': labels_y}
-    _x, _y, labels = _make_regression(
-        input_df,
+    X_train, y_train, labels = _make_regression(
+        input_df[:-except_last_n] if except_last_n != 0 else input_df,
         pattern_length,
         input_features_labels,
         output_features_labels,
@@ -57,17 +56,23 @@ def make_time_series_dataset(input_df, pattern_length, n_to_predict, input_featu
         shuffle
     )
 
-    if except_last_n == 0:
-        X_train = _x
-        y_train = _y
-        X_test = np.array([])
-        y_test = X_test
-    else:    
-        X_train, X_test, y_train, y_test = train_test_split(_x, _y, test_size=except_last_n, shuffle=False)
-
     tsd = TimeSeriesDataset(X_train, y_train, labels)
 
-    tsd.X_test = X_test
-    tsd.y_test = y_test
+    if except_last_n == 0:
+        tsd.test = None
+    else:
+        if generate_test_dataset:
+            X_test, y_test, labels = _make_regression(
+                input_df[:except_last_n],
+                pattern_length,
+                input_features_labels,
+                output_features_labels,
+                n_to_predict,
+                augmentation,
+                stride,
+                shuffle
+            )   
+
+            tsd.test = TimeSeriesDataset(X_test, y_test, labels)
 
     return tsd
\ No newline at end of file
